@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 '''
 Test suite for vdirsyncer.
 '''
@@ -21,7 +20,7 @@ def assert_item_equals(a, b):
     assert normalize_item(a) == normalize_item(b)
 
 
-VCARD_TEMPLATE = u'''BEGIN:VCARD
+VCARD_TEMPLATE = '''BEGIN:VCARD
 VERSION:3.0
 FN:Cyrus Daboo
 N:Daboo;Cyrus;;;
@@ -37,7 +36,7 @@ X-SOMETHING:{r}
 UID:{uid}
 END:VCARD'''
 
-TASK_TEMPLATE = u'''BEGIN:VCALENDAR
+TASK_TEMPLATE = '''BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//dmfs.org//mimedir.icalendar//EN
 BEGIN:VTODO
@@ -52,7 +51,7 @@ END:VTODO
 END:VCALENDAR'''
 
 
-BARE_EVENT_TEMPLATE = u'''BEGIN:VEVENT
+BARE_EVENT_TEMPLATE = '''BEGIN:VEVENT
 DTSTART:19970714T170000Z
 DTEND:19970715T035959Z
 SUMMARY:Bastille Day Party
@@ -61,10 +60,10 @@ UID:{uid}
 END:VEVENT'''
 
 
-EVENT_TEMPLATE = u'''BEGIN:VCALENDAR
+EVENT_TEMPLATE = '''BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//hacksw/handcal//NONSGML v1.0//EN
-''' + BARE_EVENT_TEMPLATE + u'''
+''' + BARE_EVENT_TEMPLATE + '''
 END:VCALENDAR'''
 
 EVENT_WITH_TIMEZONE_TEMPLATE = '''BEGIN:VCALENDAR
@@ -90,7 +89,7 @@ END:VTIMEZONE
 END:VCALENDAR'''
 
 
-SIMPLE_TEMPLATE = u'''BEGIN:FOO
+SIMPLE_TEMPLATE = '''BEGIN:FOO
 UID:{uid}
 X-SOMETHING:{r}
 HAHA:YES
