@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 '''
 General-purpose fixtures for vdirsyncer's testsuite.
 '''
@@ -27,18 +26,22 @@ else:
     del pytest_benchmark
 
 
-settings.suppress_health_check = [HealthCheck.too_slow]
-
 settings.register_profile("ci", settings(
     max_examples=1000,
     verbosity=Verbosity.verbose,
+    suppress_health_check=[HealthCheck.too_slow],
 ))
 settings.register_profile("deterministic", settings(
     derandomize=True,
-    perform_health_check=False
+    suppress_health_check=HealthCheck.all(),
+))
+settings.register_profile("dev", settings(
+    suppress_health_check=[HealthCheck.too_slow]
 ))
 
 if os.environ.get('DETERMINISTIC_TESTS', 'false').lower() == 'true':
     settings.load_profile("deterministic")
 elif os.environ.get('CI', 'false').lower() == 'true':
     settings.load_profile("ci")
+else:
+    settings.load_profile("dev")
