@@ -1,7 +1,7 @@
 import pytest
 
 
-class ServerMixin(object):
+class ServerMixin:
 
     @pytest.fixture
     def get_storage_args(self):
