@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import subprocess
 
 import pytest
@@ -24,7 +22,7 @@ class TestFilesystemStorage(StorageTests):
         return inner
 
     def test_is_not_directory(self, tmpdir):
-        with pytest.raises(IOError):
+        with pytest.raises(OSError):
             f = tmpdir.join('hue')
             f.write('stub')
             self.storage_class(str(tmpdir) + '/hue', '.txt')
@@ -32,8 +30,8 @@ class TestFilesystemStorage(StorageTests):
     def test_broken_data(self, tmpdir):
         s = self.storage_class(str(tmpdir), '.txt')
 
-        class BrokenItem(object):
-            raw = u'Ц, Ш, Л, ж, Д, З, Ю'.encode('utf-8')
+        class BrokenItem:
+            raw = 'Ц, Ш, Л, ж, Д, З, Ю'.encode()
             uid = 'jeezus'
             ident = uid
         with pytest.raises(TypeError):
@@ -42,45 +40,45 @@ class TestFilesystemStorage(StorageTests):
 
     def test_ident_with_slash(self, tmpdir):
         s = self.storage_class(str(tmpdir), '.txt')
-        s.upload(Item(u'UID:a/b/c'))
+        s.upload(Item('UID:a/b/c'))
         item_file, = tmpdir.listdir()
         assert '/' not in item_file.basename and item_file.isfile()
 
     def test_too_long_uid(self, tmpdir):
         s = self.storage_class(str(tmpdir), '.txt')
-        item = Item(u'UID:' + u'hue' * 600)
+        item = Item('UID:' + 'hue' * 600)
         href, etag = s.upload(item)
         assert item.uid not in href
 
     def test_post_hook_inactive(self, tmpdir, monkeypatch):
 
         def check_call_mock(*args, **kwargs):
-            assert False
+            raise AssertionError()
 
         monkeypatch.setattr(subprocess, 'call', check_call_mock)
 
         s = self.storage_class(str(tmpdir), '.txt', post_hook=None)
-        s.upload(Item(u'UID:a/b/c'))
+        s.upload(Item('UID:a/b/c'))
 
     def test_post_hook_active(self, tmpdir, monkeypatch):
 
         calls = []
         exe = 'foo'
 
-        def check_call_mock(l, *args, **kwargs):
+        def check_call_mock(call, *args, **kwargs):
             calls.append(True)
-            assert len(l) == 2
-            assert l[0] == exe
+            assert len(call) == 2
+            assert call[0] == exe
 
         monkeypatch.setattr(subprocess, 'call', check_call_mock)
 
         s = self.storage_class(str(tmpdir), '.txt', post_hook=exe)
-        s.upload(Item(u'UID:a/b/c'))
+        s.upload(Item('UID:a/b/c'))
         assert calls
 
     def test_ignore_git_dirs(self, tmpdir):
         tmpdir.mkdir('.git').mkdir('foo')
         tmpdir.mkdir('a')
         tmpdir.mkdir('b')
-        assert set(c['collection'] for c
-                   in self.storage_class.discover(str(tmpdir))) == {'a', 'b'}
+        assert {c['collection'] for c
+                in self.storage_class.discover(str(tmpdir))} == {'a', 'b'}
