@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import sys
 import logging
 
@@ -20,7 +18,7 @@ def test_get_storage_init_args():
     from vdirsyncer.storage.memory import MemoryStorage
 
     all, required = utils.get_storage_init_args(MemoryStorage)
-    assert all == set(['fileext', 'collection', 'read_only', 'instance_name'])
+    assert all == {'fileext', 'collection', 'read_only', 'instance_name'}
     assert not required
 
 
