@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from copy import deepcopy
 
 import hypothesis.strategies as st
@@ -32,7 +30,7 @@ def empty_storage(x):
 
 
 def items(s):
-    return set(x[1].raw for x in s.items.values())
+    return {x[1].raw for x in s.items.values()}
 
 
 def test_irrelevant_status():
@@ -49,7 +47,7 @@ def test_missing_status():
     a = MemoryStorage()
     b = MemoryStorage()
     status = {}
-    item = Item(u'asdf')
+    item = Item('asdf')
     a.upload(item)
     b.upload(item)
     sync(a, b, status)
@@ -62,8 +60,8 @@ def test_missing_status_and_different_items():
     b = MemoryStorage()
 
     status = {}
-    item1 = Item(u'UID:1\nhaha')
-    item2 = Item(u'UID:1\nhoho')
+    item1 = Item('UID:1\nhaha')
+    item2 = Item('UID:1\nhoho')
     a.upload(item1)
     b.upload(item2)
     with pytest.raises(SyncConflict):
@@ -79,8 +77,8 @@ def test_read_only_and_prefetch():
     b.read_only = True
 
     status = {}
-    item1 = Item(u'UID:1\nhaha')
-    item2 = Item(u'UID:2\nhoho')
+    item1 = Item('UID:1\nhaha')
+    item2 = Item('UID:2\nhoho')
     a.upload(item1)
     a.upload(item2)
 
@@ -152,22 +150,22 @@ def test_upload_and_update():
     b = MemoryStorage(fileext='.b')
     status = {}
 
-    item = Item(u'UID:1')  # new item 1 in a
+    item = Item('UID:1')  # new item 1 in a
     a.upload(item)
     sync(a, b, status)
     assert items(b) == items(a) == {item.raw}
 
-    item = Item(u'UID:1\nASDF:YES')  # update of item 1 in b
+    item = Item('UID:1\nASDF:YES')  # update of item 1 in b
     b.update('1.b', item, b.get('1.b')[1])
     sync(a, b, status)
     assert items(b) == items(a) == {item.raw}
 
-    item2 = Item(u'UID:2')  # new item 2 in b
+    item2 = Item('UID:2')  # new item 2 in b
     b.upload(item2)
     sync(a, b, status)
     assert items(b) == items(a) == {item.raw, item2.raw}
 
-    item2 = Item(u'UID:2\nASDF:YES')  # update of item 2 in a
+    item2 = Item('UID:2\nASDF:YES')  # update of item 2 in a
     a.update('2.a', item2, a.get('2.a')[1])
     sync(a, b, status)
     assert items(b) == items(a) == {item.raw, item2.raw}
@@ -178,9 +176,9 @@ def test_deletion():
     b = MemoryStorage(fileext='.b')
     status = {}
 
-    item = Item(u'UID:1')
+    item = Item('UID:1')
     a.upload(item)
-    item2 = Item(u'UID:2')
+    item2 = Item('UID:2')
     a.upload(item2)
     sync(a, b, status)
     b.delete('1.b', b.get('1.b')[1])
@@ -215,7 +213,7 @@ def test_insert_hash():
 def test_already_synced():
     a = MemoryStorage(fileext='.a')
     b = MemoryStorage(fileext='.b')
-    item = Item(u'UID:1')
+    item = Item('UID:1')
     a.upload(item)
     b.upload(item)
     status = {
@@ -243,14 +241,14 @@ def test_already_synced():
 def test_conflict_resolution_both_etags_new(winning_storage):
     a = MemoryStorage()
     b = MemoryStorage()
-    item = Item(u'UID:1')
+    item = Item('UID:1')
     href_a, etag_a = a.upload(item)
     href_b, etag_b = b.upload(item)
     status = {}
     sync(a, b, status)
     assert status
-    item_a = Item(u'UID:1\nitem a')
-    item_b = Item(u'UID:1\nitem b')
+    item_a = Item('UID:1\nitem a')
+    item_b = Item('UID:1\nitem b')
     a.update(href_a, item_a, etag_a)
     b.update(href_b, item_b, etag_b)
     with pytest.raises(SyncConflict):
@@ -264,13 +262,13 @@ def test_conflict_resolution_both_etags_new(winning_storage):
 def test_updated_and_deleted():
     a = MemoryStorage()
     b = MemoryStorage()
-    href_a, etag_a = a.upload(Item(u'UID:1'))
+    href_a, etag_a = a.upload(Item('UID:1'))
     status = {}
     sync(a, b, status, force_delete=True)
 
     (href_b, etag_b), = b.list()
     b.delete(href_b, etag_b)
-    updated = Item(u'UID:1\nupdated')
+    updated = Item('UID:1\nupdated')
     a.update(href_a, updated, etag_a)
     sync(a, b, status, force_delete=True)
 
@@ -280,8 +278,8 @@ def test_updated_and_deleted():
 def test_conflict_resolution_invalid_mode():
     a = MemoryStorage()
     b = MemoryStorage()
-    item_a = Item(u'UID:1\nitem a')
-    item_b = Item(u'UID:1\nitem b')
+    item_a = Item('UID:1\nitem a')
+    item_b = Item('UID:1\nitem b')
     a.upload(item_a)
     b.upload(item_b)
     with pytest.raises(ValueError):
@@ -291,7 +289,7 @@ def test_conflict_resolution_invalid_mode():
 def test_conflict_resolution_new_etags_without_changes():
     a = MemoryStorage()
     b = MemoryStorage()
-    item = Item(u'UID:1')
+    item = Item('UID:1')
     href_a, etag_a = a.upload(item)
     href_b, etag_b = b.upload(item)
     status = {'1': (href_a, 'BOGUS_a', href_b, 'BOGUS_b')}
@@ -326,7 +324,7 @@ def test_uses_get_multi(monkeypatch):
 
     a = MemoryStorage()
     b = MemoryStorage()
-    item = Item(u'UID:1')
+    item = Item('UID:1')
     expected_href, etag = a.upload(item)
 
     sync(a, b, {})
@@ -336,8 +334,8 @@ def test_uses_get_multi(monkeypatch):
 def test_empty_storage_dataloss():
     a = MemoryStorage()
     b = MemoryStorage()
-    a.upload(Item(u'UID:1'))
-    a.upload(Item(u'UID:2'))
+    a.upload(Item('UID:1'))
+    a.upload(Item('UID:2'))
     status = {}
     sync(a, b, status)
     with pytest.raises(StorageEmpty):
@@ -350,22 +348,22 @@ def test_empty_storage_dataloss():
 def test_no_uids():
     a = MemoryStorage()
     b = MemoryStorage()
-    a.upload(Item(u'ASDF'))
-    b.upload(Item(u'FOOBAR'))
+    a.upload(Item('ASDF'))
+    b.upload(Item('FOOBAR'))
     status = {}
     sync(a, b, status)
-    assert items(a) == items(b) == {u'ASDF', u'FOOBAR'}
+    assert items(a) == items(b) == {'ASDF', 'FOOBAR'}
 
 
 def test_changed_uids():
     a = MemoryStorage()
     b = MemoryStorage()
-    href_a, etag_a = a.upload(Item(u'UID:A-ONE'))
-    href_b, etag_b = b.upload(Item(u'UID:B-ONE'))
+    href_a, etag_a = a.upload(Item('UID:A-ONE'))
+    href_b, etag_b = b.upload(Item('UID:B-ONE'))
     status = {}
     sync(a, b, status)
 
-    a.update(href_a, Item(u'UID:A-TWO'), etag_a)
+    a.update(href_a, Item('UID:A-TWO'), etag_a)
     sync(a, b, status)
 
 
@@ -383,8 +381,8 @@ def test_partial_sync_revert():
     a = MemoryStorage(instance_name='a')
     b = MemoryStorage(instance_name='b')
     status = {}
-    a.upload(Item(u'UID:1'))
-    b.upload(Item(u'UID:2'))
+    a.upload(Item('UID:1'))
+    b.upload(Item('UID:2'))
     b.read_only = True
 
     sync(a, b, status, partial_sync='revert')
@@ -418,13 +416,13 @@ def test_ident_conflict(sync_inbetween):
     a = MemoryStorage()
     b = MemoryStorage()
     status = {}
-    href_a, etag_a = a.upload(Item(u'UID:aaa'))
-    href_b, etag_b = a.upload(Item(u'UID:bbb'))
+    href_a, etag_a = a.upload(Item('UID:aaa'))
+    href_b, etag_b = a.upload(Item('UID:bbb'))
     if sync_inbetween:
         sync(a, b, status)
 
-    a.update(href_a, Item(u'UID:xxx'), etag_a)
-    a.update(href_b, Item(u'UID:xxx'), etag_b)
+    a.update(href_a, Item('UID:xxx'), etag_a)
+    a.update(href_b, Item('UID:xxx'), etag_b)
 
     with pytest.raises(IdentConflict):
         sync(a, b, status)
@@ -441,7 +439,7 @@ def test_moved_href():
     a = MemoryStorage()
     b = MemoryStorage()
     status = {}
-    href, etag = a.upload(Item(u'UID:haha'))
+    href, etag = a.upload(Item('UID:haha'))
     sync(a, b, status)
 
     b.items['lol'] = b.items.pop('haha')
@@ -476,26 +474,26 @@ def test_bogus_etag_change():
     a = MemoryStorage()
     b = MemoryStorage()
     status = {}
-    href_a, etag_a = a.upload(Item(u'UID:ASDASD'))
+    href_a, etag_a = a.upload(Item('UID:ASDASD'))
     sync(a, b, status)
     assert len(status) == len(list(a.list())) == len(list(b.list())) == 1
 
     (href_b, etag_b), = b.list()
-    a.update(href_a, Item(u'UID:ASDASD'), etag_a)
-    b.update(href_b, Item(u'UID:ASDASD\nACTUALCHANGE:YES'), etag_b)
+    a.update(href_a, Item('UID:ASDASD'), etag_a)
+    b.update(href_b, Item('UID:ASDASD\nACTUALCHANGE:YES'), etag_b)
 
     b.delete = b.update = b.upload = blow_up
 
     sync(a, b, status)
     assert len(status) == 1
-    assert items(a) == items(b) == {u'UID:ASDASD\nACTUALCHANGE:YES'}
+    assert items(a) == items(b) == {'UID:ASDASD\nACTUALCHANGE:YES'}
 
 
 def test_unicode_hrefs():
     a = MemoryStorage()
     b = MemoryStorage()
     status = {}
-    href, etag = a.upload(Item(u'UID:äää'))
+    href, etag = a.upload(Item('UID:äää'))
     sync(a, b, status)
 
 
@@ -565,7 +563,7 @@ class SyncMachine(RuleBasedStateMachine):
           uid=uid_strategy,
           etag=st.text())
     def upload(self, storage, uid, etag):
-        item = Item(u'UID:{}'.format(uid))
+        item = Item('UID:{}'.format(uid))
         storage.items[uid] = (etag, item)
 
     @rule(storage=Storage, href=st.text())
