@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
-
 import contextlib
 import functools
 
 from .. import exceptions
 from ..utils import uniq
-from ..utils.vobject import Item  # noqa
 
 
 def mutating_storage_method(f):
@@ -21,12 +18,12 @@ class StorageMeta(type):
     def __init__(cls, name, bases, d):
         for method in ('update', 'upload', 'delete'):
             setattr(cls, method, mutating_storage_method(getattr(cls, method)))
-        return super(StorageMeta, cls).__init__(name, bases, d)
+        return super().__init__(name, bases, d)
 
 
 class Storage(metaclass=StorageMeta):
 
-    '''Superclass of all storages, mainly useful to summarize the interface to
+    '''Superclass of all storages, interface that all storages have to
     implement.
 
     Terminology:
@@ -34,7 +31,7 @@ class Storage(metaclass=StorageMeta):
           contact.
       - HREF: String; Per-storage identifier of item, might be UID. The reason
           items aren't just referenced by their UID is because the CalDAV and
-          CardDAV specifications make this imperformant to implement.
+          CardDAV specifications make this unperformant to implement.
       - ETAG: String; Checksum of item, or something similar that changes when
           the item does.
 
@@ -117,7 +114,7 @@ class Storage(metaclass=StorageMeta):
 
         return '<{}(**{})>'.format(
             self.__class__.__name__,
-            dict((x, getattr(self, x)) for x in self._repr_attributes)
+            {x: getattr(self, x) for x in self._repr_attributes}
         )
 
     def list(self):
@@ -166,6 +163,11 @@ class Storage(metaclass=StorageMeta):
     def upload(self, item):
         '''Upload a new item.
 
+        In cases where the new etag cannot be atomically determined (i.e. in
+        the same "transaction" as the upload itself), this method may return
+        `None` as etag. This special case only exists because of DAV. Avoid
+        this situation whenever possible.
+
         :raises: :exc:`vdirsyncer.exceptions.PreconditionFailed` if there is
             already an item with that href.
 
@@ -176,6 +178,8 @@ class Storage(metaclass=StorageMeta):
     def update(self, href, item, etag):
         '''Update an item.
 
+        The etag may be none in some cases, see `upload`.
+
         :raises: :exc:`vdirsyncer.exceptions.PreconditionFailed` if the etag on
             the server doesn't match the given etag or if the item doesn't
             exist.
@@ -236,4 +240,7 @@ class Storage(metaclass=StorageMeta):
 
 
 def normalize_meta_value(value):
-    return (value or u'').strip()
+    # `None` is returned by iCloud for empty properties.
+    if not value or value == 'None':
+        value = ''
+    return value.strip()
